powered by
Creates a 'promise' from a 'mirai' or 'recvAio'.
# S3 method for mirai as.promise(x)# S3 method for recvAio as.promise(x)
# S3 method for recvAio as.promise(x)
A 'promise' object.
an object of class 'mirai' or 'recvAio'.
This function is an S3 method for the generic as.promise for class 'mirai' or 'recvAio'.
as.promise
polling may be used to customise the frequency with which to poll for promise resolution (defaults to every 100 milliseconds).
polling
if (interactive()) { # Only run examples in interactive R sessions p <- promises::as.promise(mirai::mirai("example")) print(p) promises::is.promise(p) }
Run the code above in your browser using DataLab